
#################################################
*PYSICA* PYthon tools for SImulation and CAlculus
#################################################

.. contents::

Introduction
============

This package contains some tools I have developed for my research work.
They are grouped in a single package since many of them make use of others.



Package structure
=================


List of modules in the main package
-----------------------------------

*constants*
    some physical constants used in various modules and packages
*parameters*
    some parameters used in various modules and packages

    
List of Sub-packages in the main package
----------------------------------------

*analysis*
    some modules which can be helpful to manage distribution functions and data histograms
*fortran*
    some general purpose modules compiled from Fortran using f2py
*functions*
    some general purpose functions    
*io*
    some tools for input-output management    
*managers*
    some modules and packages used to manage input/output of data from/to ascii files
    to print physical quantities managing the unit prefixes
    and to plot data by means of the gnuplot program
*plasmapro*
    a package containing tools for the simulation of plasma discharges
    

    
analysis
--------
*univariate*

*bivariate*

*spectra*




functions
---------

*physics*
    functions used to calculate or convert some physical quantities
*optical*
    functions for analysis of the optical properties of thin films (absorption, reflection)
*mathematics*
    functions used to calculate averages, derivatives and other calculations
*pdf*
    collection of probability distribution functions used in the package
*statistics*
    some statistical tools


fortran
-------
*fmatehmatics*
    mathematical functions written in Fortran: weighted average


io 
---


managers
--------


plasmapro
---------




